@@ -207,9 +207,11 @@ class Pie(ChartPart):
                 isinstance(series_obj["universalTransition"], bool)
                 and series_obj["universalTransition"]
             ):
+                
+
                 series_obj["universalTransition"] = {
                     "enabled": True,
-                    "seriesKey": list(data.index.values),
+                    "seriesKey": data.index.values[0] if len(data.index.values)==1 else list(data.index.values),
                 }
             spec.add_series(series_obj)
 
